@@ -21,6 +21,12 @@
 #'   unnecessary calculation.
 #' @param which.bound Returns BMDU if which.bound = "upper"; returns BMDL if
 #'   which.bound = "lower".
+#' @param poly2.biphasic If poly2.biphasic = TRUE, constraints are set to allow
+#'   for the polynomial 2 model fit to be bi-phasic (i.e. non-monotonic).
+#' @param x_v The vertex of the quadratic/parabolic fit.
+#'   Only in use when estimating the BMDL and BMDU values for the "poly2" model
+#'   when poly2.biphasic = TRUE. No default is set.
+#'
 #' @importFrom stats uniroot
 #' @return Returns either the BMDU or BMDL.
 #' @export
@@ -32,7 +38,12 @@
 #' bmdbounds(fit_method = "hill", bmr = .5, pars, conc, resp)
 #' bmdbounds(fit_method = "hill", bmr = .5, pars, conc, resp, which.bound = "upper")
 
-bmdbounds = function(fit_method, bmr, pars, conc, resp, onesidedp = .05, bmd = NULL, which.bound = "lower"){
+bmdbounds = function(fit_method, bmr, pars, conc, resp, onesidedp = .05, bmd = NULL, which.bound = "lower", poly2.biphasic = TRUE,x_v){
+
+  # check if the if the biphasic poly2 has the vertex passed
+  if(poly2.biphasic & fit_method == "poly2" & missing(x_v)){
+    stop("Biphasic Polynomial 2 models require the vertex to estimate BMDL & BMDU.")
+  }
 
   #calculate bmd, if necessary
   if(is.null(bmd)) bmd = acy(bmr, as.list(pars), type = fit_method)
@@ -46,7 +57,7 @@ bmdbounds = function(fit_method, bmr, pars, conc, resp, onesidedp = .05, bmd = N
   if(which.bound == "lower") {
     xs = 10^seq(-5,log10(bmd), length.out = 100)
     ys = sapply(X = xs, FUN = bmdobj, fname = fname, bmr = bmr, conc = conc, resp = resp, ps = pars, mll = maxloglik,
-                onesp = onesidedp, partype = 2)
+                onesp = onesidedp, partype = 2,poly2.biphasic = poly2.biphasic,x_v = x_v)
     if(!any(ys >= 0, na.rm = TRUE) | !any(ys < 0, na.rm = TRUE)) return(NA_real_)
     bmdrange = c(max(xs[ys >= 0]), bmd)
   }
@@ -56,15 +67,14 @@ bmdbounds = function(fit_method, bmr, pars, conc, resp, onesidedp = .05, bmd = N
       xs = 10^seq(log10(bmd), log10(toploc), length.out = 100)
     } else xs = 10^seq(log10(bmd), 5, length.out = 100)
     ys = sapply(X = xs, FUN = bmdobj, fname = fname, bmr = bmr, conc = conc, resp = resp, ps = pars, mll = maxloglik,
-                onesp = onesidedp, partype = 2)
+                onesp = onesidedp, partype = 2,poly2.biphasic = poly2.biphasic,x_v = x_v)
     if(!any(ys >= 0, na.rm = TRUE) | !any(ys < 0, na.rm = TRUE)) return(NA_real_)
-
     bmdrange = c(bmd, min(xs[ys >= 0]))
   }
 
   #use type 2 param. only
   out = try(uniroot(bmdobj, bmdrange, fname = fname, bmr = bmr, conc = conc, resp = resp, ps = pars, mll = maxloglik,
-                onesp = onesidedp, partype = 2)$root)
+                onesp = onesidedp, partype = 2,poly2.biphasic = poly2.biphasic,x_v = x_v)$root)
 
   #sometimes there's no lower/upper bound because the model is such a poor fit, in this case, return NA
   if(is(out,"try-error")) return(NA_real_) else return(out)
