@@ -17,6 +17,9 @@
 #' @param verbose If TRUE, gives optimization and hessian inversion details.
 #' @param nofit If nofit = TRUE, returns formatted output filled with missing values.
 #' @param dmin Minimum allowed value of p.
+#' @param errfun Which error distribution to assume for each point, defaults to
+#'   "dt4". "dt4" is the original 4 degrees of freedom t-distribution. Another
+#'   supported distribution is "dnorm", the normal distribution.
 #'
 #' @importFrom methods is
 #' @importFrom numDeriv hessian
@@ -31,7 +34,7 @@
 #'
 #' @examples
 #' fitexp3(c(.03,.1,.3,1,3,10,30,100), c(0,0,.1, .2, .4, 1, 4, 50))
-fitexp3 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FALSE, dmin = .3){
+fitexp3 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FALSE, dmin = .3, errfun = "dt4"){
 
   fenv <- environment()
   #initialize myparams
@@ -106,7 +109,8 @@ fitexp3 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FA
                                          maxit = 6000),
                           conc = conc,
                           resp = resp,
-                          fname = "exp3"),
+                          fname = "exp3",
+                          errfun = errfun),
               silent = !verbose)
 
 
@@ -130,7 +134,8 @@ fitexp3 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FA
                                    fit$par,
                                    conc = conc,
                                    resp = resp,
-                                   fname = "exp3")),
+                                   fname = "exp3",
+                                   errfun = errfun)),
                     silent = !verbose)
 
     if (!is(fit$cov, "try-error")) { # Could invert gnls Hessian
