@@ -17,6 +17,9 @@
 #' @param verbose If TRUE, gives optimization and hessian inversion details.
 #' @param nofit If nofit = TRUE, returns formatted output filled with missing values.
 #' @param dmin Minimum allowed value of p.
+#' @param errfun Which error distribution to assume for each point, defaults to
+#'   "dt4". "dt4" is the original 4 degrees of freedom t-distribution. Another
+#'   supported distribution is "dnorm", the normal distribution.
 #'
 #' @importFrom methods is
 #' @importFrom numDeriv hessian
@@ -31,7 +34,7 @@
 #'
 #' @examples
 #' fitexp5(c(.03,.1,.3,1,3,10,30,100), c(0,0,.1, .2, .5, 1, 1.5, 2))
-fitexp5 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FALSE, dmin = .3){
+fitexp5 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FALSE, dmin = .3, errfun = "dt4"){
 
   fenv <- environment()
   #initialize myparams
@@ -105,7 +108,8 @@ fitexp5 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FA
                                          maxit = 6000),
                           conc = conc,
                           resp = resp,
-                          fname = "exp5"),
+                          fname = "exp5",
+                          errfun = errfun),
               silent = !verbose)
 
 
@@ -129,7 +133,8 @@ fitexp5 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FA
                                    fit$par,
                                    conc = conc,
                                    resp = resp,
-                                   fname = "exp5")),
+                                   fname = "exp5",
+                                   errfun = errfun)),
                     silent = !verbose)
 
     if (!is(fit$cov, "try-error")) { # Could invert gnls Hessian
