@@ -15,6 +15,9 @@
 #'   will be positive only.
 #' @param verbose If TRUE, gives optimization and hessian inversion details.
 #' @param nofit If nofit = TRUE, returns formatted output filled with missing values.
+#' @param errfun Which error distribution to assume for each point, defaults to
+#'   "dt4". "dt4" is the original 4 degrees of freedom t-distribution. Another
+#'   supported distribution is "dnorm", the normal distribution.
 #'
 #' @importFrom methods is
 #' @importFrom numDeriv hessian
@@ -29,7 +32,7 @@
 #'
 #' @examples
 #' fitpoly1(c(.03,.1,.3,1,3,10,30,100), c(0,.01,.1, .1, .2, .5, 2, 5))
-fitpoly1 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FALSE){
+fitpoly1 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = FALSE, errfun = "dt4"){
 
   fenv <- environment()
   #initialize myparams
@@ -95,7 +98,8 @@ fitpoly1 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = F
                                          maxit = 6000),
                           conc = conc,
                           resp = resp,
-                          fname = "poly1"),
+                          fname = "poly1",
+                          errfun = errfun),
               silent = !verbose)
 
   ## Generate some summary statistics
@@ -118,7 +122,8 @@ fitpoly1 = function(conc, resp, bidirectional = TRUE, verbose = FALSE, nofit = F
                                    fit$par,
                                    conc = conc,
                                    resp = resp,
-                                   fname = "poly1")),
+                                   fname = "poly1",
+                                   errfun = errfun)),
                     silent = !verbose)
 
     if (!is(fit$cov, "try-error")) { # Could invert gnls Hessian
